---
title: Other features
---

## List of features

::: gentropy.dataset.l2g_features.other.GeneCountFeature
::: gentropy.dataset.l2g_features.other.ProteinGeneCountFeature
::: gentropy.dataset.l2g_features.other.ProteinCodingFeature
::: gentropy.dataset.l2g_features.other.CredibleSetConfidenceFeature

## Common logic

::: gentropy.dataset.l2g_features.other.common_genecount_feature_logic
::: gentropy.dataset.l2g_features.other.is_protein_coding_feature_logic
